@@ -13,6 +13,7 @@
 import cannerflow.workspace
 import cannerflow.constants
 import cannerflow.exceptions
+import cannerflow.utils
 
 __all__ = ["bootstrap", "Client"]
 
@@ -22,28 +23,26 @@ def bootstrap(*args, **kwargs):
 class Client(object):
     def __init__(self,
         endpoint,
-        token,
-        workspaceId,
+        headers,
+        workspace_id,
         replaceLocalhostString=None
     ):
         self.workspace = cannerflow.workspace.Workspace(
             endpoint=endpoint,
-            headers={
-                "Authorization": f"Bearer {token}"
-            },
-            workspaceId=workspaceId,
+            headers=headers,
+            workspace_id=workspace_id,
             replaceLocalhostString=replaceLocalhostString
         )
 
     # SQL
-    def use_saved_query(self, title):
+    def use_saved_query(self, title, cache_refresh=False, cache_ttl=86400, data_format="list"):
         query = self.workspace.saved_query.get(title)
-        return self.execute(query['sql'])
+        return self.gen_query(sql=query['sql'], cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format)
     def list_saved_query(self):
         return self.workspace.saved_query.list_title()
-    def execute(self, sql):
-        cursor = self.workspace.statement.execute(sql);
-        return cursor
+    def gen_query(self, sql, cache_refresh=False, cache_ttl=86400, data_format="list"):
+        query = self.workspace.gen_query(sql, cache_refresh=cache_refresh, cache_ttl=cache_ttl, data_format=data_format);
+        return query
 
     # files
     def list_file(self):
